Index: trunk/ppSub/src/ppSubCamera.c
===================================================================
--- trunk/ppSub/src/ppSubCamera.c	(revision 21360)
+++ trunk/ppSub/src/ppSubCamera.c	(revision 21374)
@@ -6,6 +6,6 @@
  *
  *  @author IfA
- *  @version $Revision: 1.32 $ $Name: not supported by cvs2svn $
- *  @date $Date: 2009-02-06 01:37:17 $
+ *  @version $Revision: 1.33 $ $Name: not supported by cvs2svn $
+ *  @date $Date: 2009-02-06 03:20:02 $
  *  Copyright 2009 Institute for Astronomy, University of Hawaii
  */
@@ -39,12 +39,12 @@
     }
 
-    // Input weight map
-    pmFPAfile *inputWeight = pmFPAfileBindFromArgs(&status, input, config, "PPSUB.INPUT.WEIGHT", "INPUT.WEIGHT");
-    if (!status) {
-        psError (PS_ERR_UNKNOWN, false, "Failed to load file definition PPSUB.INPUT.WEIGHT");
+    // Input variance map
+    pmFPAfile *inputVariance = pmFPAfileBindFromArgs(&status, input, config, "PPSUB.INPUT.VARIANCE", "INPUT.VARIANCE");
+    if (!status) {
+        psError (PS_ERR_UNKNOWN, false, "Failed to load file definition PPSUB.INPUT.VARIANCE");
         return NULL;
     }
-    if (inputWeight && inputWeight->type != PM_FPA_FILE_WEIGHT) {
-        psError(PS_ERR_IO, true, "PPSUB.INPUT.WEIGHT is not of type WEIGHT");
+    if (inputVariance && inputVariance->type != PM_FPA_FILE_VARIANCE) {
+        psError(PS_ERR_IO, true, "PPSUB.INPUT.VARIANCE is not of type VARIANCE");
         return false;
     }
@@ -73,12 +73,12 @@
     }
 
-    // Reference weight map
-    pmFPAfile *refWeight = pmFPAfileBindFromArgs(&status, ref, config, "PPSUB.REF.WEIGHT", "REF.WEIGHT");
-    if (!status) {
-        psError (PS_ERR_UNKNOWN, false, "Failed to load file definition PPSUB.REF.WEIGHT");
+    // Reference variance map
+    pmFPAfile *refVariance = pmFPAfileBindFromArgs(&status, ref, config, "PPSUB.REF.VARIANCE", "REF.VARIANCE");
+    if (!status) {
+        psError (PS_ERR_UNKNOWN, false, "Failed to load file definition PPSUB.REF.VARIANCE");
         return NULL;
     }
-    if (refWeight && refWeight->type != PM_FPA_FILE_WEIGHT) {
-        psError(PS_ERR_IO, true, "PPSUB.REF.WEIGHT is not of type WEIGHT");
+    if (refVariance && refVariance->type != PM_FPA_FILE_VARIANCE) {
+        psError(PS_ERR_IO, true, "PPSUB.REF.VARIANCE is not of type VARIANCE");
         return false;
     }
@@ -108,16 +108,16 @@
     outMask->save = true;
 
-    // Output weight
-    if (inputWeight && refWeight) {
-        pmFPAfile *outWeight = pmFPAfileDefineOutput(config, output->fpa, "PPSUB.OUTPUT.WEIGHT");
-        if (!outWeight) {
-            psError(PS_ERR_IO, false, _("Unable to generate output file from PPSUB.OUTPUT.WEIGHT"));
-            return false;
-        }
-        if (outWeight->type != PM_FPA_FILE_WEIGHT) {
-            psError(PS_ERR_IO, true, "PPSUB.OUTPUT.WEIGHT is not of type WEIGHT");
-            return false;
-        }
-        outWeight->save = true;
+    // Output variance
+    if (inputVariance && refVariance) {
+        pmFPAfile *outVariance = pmFPAfileDefineOutput(config, output->fpa, "PPSUB.OUTPUT.VARIANCE");
+        if (!outVariance) {
+            psError(PS_ERR_IO, false, _("Unable to generate output file from PPSUB.OUTPUT.VARIANCE"));
+            return false;
+        }
+        if (outVariance->type != PM_FPA_FILE_VARIANCE) {
+            psError(PS_ERR_IO, true, "PPSUB.OUTPUT.VARIANCE is not of type VARIANCE");
+            return false;
+        }
+        outVariance->save = true;
     }
 
@@ -146,16 +146,16 @@
     // XXX should be based on recipe : inConvMask->save = true;
 
-    // Convolved input weight
-    if (inputWeight) {
-        pmFPAfile *inConvWeight = pmFPAfileDefineOutput(config, inConv->fpa, "PPSUB.INPUT.CONV.WEIGHT");
-        if (!inConvWeight) {
-            psError(PS_ERR_IO, false, _("Unable to generate output file from PPSUB.OUTPUT.WEIGHT"));
-            return false;
-        }
-        if (inConvWeight->type != PM_FPA_FILE_WEIGHT) {
-            psError(PS_ERR_IO, true, "PPSUB.INPUT.CONV.WEIGHT is not of type WEIGHT");
-            return false;
-        }
-        // XXX should be based on recipe : inConvWeight->save = true;
+    // Convolved input variance
+    if (inputVariance) {
+        pmFPAfile *inConvVariance = pmFPAfileDefineOutput(config, inConv->fpa, "PPSUB.INPUT.CONV.VARIANCE");
+        if (!inConvVariance) {
+            psError(PS_ERR_IO, false, _("Unable to generate output file from PPSUB.OUTPUT.VARIANCE"));
+            return false;
+        }
+        if (inConvVariance->type != PM_FPA_FILE_VARIANCE) {
+            psError(PS_ERR_IO, true, "PPSUB.INPUT.CONV.VARIANCE is not of type VARIANCE");
+            return false;
+        }
+        // XXX should be based on recipe : inConvVariance->save = true;
     }
 
@@ -184,16 +184,16 @@
     // XXX should be based on recipe : refConvMask->save = true;
 
-    // Convolved ref weight
-    if (refWeight) {
-        pmFPAfile *refConvWeight = pmFPAfileDefineOutput(config, refConv->fpa, "PPSUB.REF.CONV.WEIGHT");
-        if (!refConvWeight) {
-            psError(PS_ERR_IO, false, _("Unable to generate output file from PPSUB.OUTPUT.WEIGHT"));
-            return false;
-        }
-        if (refConvWeight->type != PM_FPA_FILE_WEIGHT) {
-            psError(PS_ERR_IO, true, "PPSUB.REF.CONV.WEIGHT is not of type WEIGHT");
-            return false;
-        }
-        // XXX should be based on recipe : refConvWeight->save = true;
+    // Convolved ref variance
+    if (refVariance) {
+        pmFPAfile *refConvVariance = pmFPAfileDefineOutput(config, refConv->fpa, "PPSUB.REF.CONV.VARIANCE");
+        if (!refConvVariance) {
+            psError(PS_ERR_IO, false, _("Unable to generate output file from PPSUB.OUTPUT.VARIANCE"));
+            return false;
+        }
+        if (refConvVariance->type != PM_FPA_FILE_VARIANCE) {
+            psError(PS_ERR_IO, true, "PPSUB.REF.CONV.VARIANCE is not of type VARIANCE");
+            return false;
+        }
+        // XXX should be based on recipe : refConvVariance->save = true;
     }
 
